<?php

/**
 * @file
 * Context reaction plugin
 */
class ds_context_reaction_fields_visibility extends context_reaction {

  function options_form($context) {

    $saved = $this->fetch_from_context($context);

    $form['debug'] = array(
      '#type' => 'value',
      '#value' => TRUE,
    );

    $form['visibility'] = array(
      '#title' => t("Visibility"),
      '#type' => 'radios',
      '#options' => array(
        "show" => t("Show"),
        "hide" => t("Hide")
      ),
      "#default_value" => isset($saved["visibility"]) ? $saved["visibility"] : null
    );
    module_load_include("inc", "ds", "ds.registry");
    module_load_include("inc", "ds", "ds.layout");

    $entities = entity_get_info();

    foreach ($entities as $entity_type => $entity) {
      foreach ($entity['bundles'] as $bundle_type => $bundle) {
        if (isset($bundle['layouts']) && count($bundle['layouts'])) {
          foreach ($bundle["layouts"] as $layout_name => $layout) {

            if (!isset($layout["settings"]["fields"]) || !count($layout["settings"]["fields"])) {
              continue;
            }

            $select = array();

            foreach ($layout["settings"]["fields"] as $field_name => $region) {
              $select[$region][$field_name] = $field_name;
            }

            if (count($select)) {

              $default_value = isset($saved["$entity_type|$bundle_type|$layout_name"]['fields']) ? $saved["$entity_type|$bundle_type|$layout_name"]['fields'] : null;

              // layout fieldset
              $form[$entity_type . '|' . $bundle_type . '|' . $layout_name] = array(
                "#title" => $entity['label'] . ' » ' . $bundle['label'] . ' » ' . $layout['label'],
                "#type" => "fieldset",
                "#collapsed" => (is_null($default_value) || !count($default_value)),
                "#collapsible" => true,
              );

              $form["$entity_type|$bundle_type|$layout_name"]['fields'] = array(
                "#title" => t("Fields"),
                "#type" => "select",
                "#multiple" => true,
                "#size" => 10,
                "#options" => $select,
                "#default_value" => $default_value
              );
            }
          }
        }// !layout
      }// !bundle
    }// !entity

    return $form;
  }

  function options_form_submit($values) {
    return $values;
  }

  /**
   * Executes the reaction when all conditions are met
   * Set an "hidden" flag to the field passed as reference
   *
   * @param array $field_name the key name of the field
   * @param string $field the field informations as reference
   */
  function execute($field_name, &$field) {
    $layout = ds_get_layout($field['entity_type'], $field['bundle'], $field['view_mode']);
    $contexts = $this->get_contexts();

    foreach ($contexts as $contexts_name => $context) {
      $reaction_settings = $context->reactions["ds_context_reaction_fields_visibility"];

      $selected_field = null;
      if (isset($reaction_settings["{$field['entity_type']}|{$field['bundle']}|default"]['fields'][$field_name])) {
        $selected_field = $reaction_settings["{$field['entity_type']}|{$field['bundle']}|default"]['fields'][$field_name];
      }
      if (isset($reaction_settings["{$field['entity_type']}|{$field['bundle']}|{$field['view_mode']}"]['fields'][$field_name])) {
        $selected_field = $reaction_settings["{$field['entity_type']}|{$field['bundle']}|{$field['view_mode']}"]['fields'][$field_name];
      }

      if ($selected_field) {
        $visibility_hide = ($reaction_settings['visibility'] == 'hide') ? true : false;
        $field['hidden'] = $visibility_hide;
        return null;
      }
      // by default is visible
      $field['hidden'] = false;
    }
  }

}